package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````V!8``#0```"`E`````0`!30`(``'
M`"@`&P`:``8````T````-````#0```#@````X`````0````$`````P```!0!
M```4`0``%`$``!<````7````!`````$````!````````````````````L(X`
M`+".```%```````!``$```"PC@``L(X!`+".`0"X`@``%`,```8```````$`
M`@```+R.``"\C@$`O(X!`/````#P````!@````0````$````+`$``"P!```L
M`0``3````$P````$````!````%#E=&2XAP``N(<``+B'```,`0``#`$```0`
M```$````+W5S<B]L:6)E>&5C+VQD+F5L9E]S;P``!P````0````!````3F5T
M0E-$``#`K](U!`````0````#````4&%8```````'````"0````4```!.971"
M4T0``&5A<FUV-VAF`````&$```!L```````````````Q````#@``````````
M````.0````\```!!`````````#```````````P```$\```!D`````````"``
M``!.````!@```!X````5`````````$0```!9````8``````````8````/0``
M`%L```!E`````````&@```!J````+P```!,```!:````1@```!8```!?````
M2`````````!+````1P```#8```!>````)@```"H`````````!P```%``````
M````#````"P```!K````70```$T````A````40```&D`````````8@``````
M```9````+@```$(````````````````````2````,P`````````*````8P``
M`"L`````````"0`````````D````.@````````!2````!0```$D````<````
M/`````````````````````````!,`````````#L```!5````9@````````!G
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````!0`````````
M`````````````````````````````````````",````B`````````"D`````
M````"P```"<````H````+0``````````````#0`````````=````&P```#4`
M```:```````````````1`````````#0````R````.````!\`````````````
M``````````````````0```````````````````!#````)0``````````````
M`````!<`````````0````$4````(````````````````````/P````````!4
M``````````````!8```````````````^````5P````````!3`````````$H`
M```0``````````````!6````7````#<```!A````````````````````````
M````````````V!8````````#``L``````+B.`0```````P`1`)D`````````
M`````!(````,```````````````2````%```````````````$@```'H#```L
M(@``"````!(`"P`<```````````````B````*P``````````````$@```$,#
M`````````````!(````Q```````````````2````BP,``&B1`0``````$``5
M`#@``````````````!(```"9`P``S"D``"`````2``L`/P``````````````
M$@```%`#`````````````!(```!'```````````````2````M`,``!0T``!H
M````$@`+`(H``````````````!(```#(`P``Q)$!```````0`!4`3P``````
M````````$@```,`#``!HD0$``````!``%`!?```````````````2````;@``
M````````````$@```'0``````````````!(```![```````````````2````
MA0``````````````$@```(\``````````````!(```#'`P``Q)$!```````0
M`!4`F```````````````$@```%<"`````````````!(```">````````````
M```2````I0``````````````$@```+,``````````````!(```#$````````
M```````1````T0``````````````$@```-,#``"P)```,````!(`"P#@`P``
MX"0``&`````2``L`[`,``.`J``"D!@``$@`+`-\``````````````!8```#R
M```````````````2````8@,`````````````$@```/T``````````````!(`
M```&`0``P)$!``0````1`!4`#@$`````````````$@```!<!````````````
M`!(````Y`P`````````````2````(P$`````````````$@```"H!````````
M`````!(```#Y`P``Y$```!@!```2``L`/0$`````````````$0```$\!````
M`````````!(```!?`0`````````````2````;0$`````````````$@```'(!
M`````````````!$```"!`0`````````````2````!`0``&21`0`$````$0`4
M`)`!`````````````!(```"<`0`````````````2````L0$`````````````
M$@```+P!`````````````!(```!U`P``Q)$!```````0`!4`\P(`````````
M````$@```,\!`````````````!(```!'!```V!8````````2``L`W0$`````
M````````$@```.4!`````````````"(```#]`0`````````````2````"0(`
M````````````$@````X$``#$D0$``````!``%0`6!```0"4``,P!```2``L`
M#P(`````````````(@```"4"`````````````!(````P`@`````````````2
M````(P0``/Q!``!T`0``$@`+`$$"`````````````!(````M!```:)$!````
M```0`!4`.00``$PA``!H````$@`+`$$$``!,1```D`(``!(`"P!(`@``````
M```````2````1@0``-@6````````$@`+`$\"`````````````!(```!.!```
M-"(``'P"```2``L`6P0``.PI``#T````$@`+`%8"`````````````!(```!M
M!```#"<``(`````2``L`7P(`````````````$@```'`"`````````````!(`
M```"`P`````````````2````=P(`````````````$@```'L$``",)P``8```
M`!(`"P"&`@`````````````2````CP(`````````````$@```)4"````````
M`````!(````L`P`````````````2````F@(`````````````$@```!\#``"$
MD0$`!````!$`%0"B`@`````````````2````5P,`````````````$@```*D"
M`````````````!(```"#!```@$```&0````2``L`L`(`````````````$@``
M`+\"`````````````!$````4`P``()$!``0````1`!0`C`0``(0Q``"0`@``
M$@`+`#8!`````````````!(```#$`@`````````````2````:0,`````````
M````$@````!L:6)P97)L+G-O`')E86QL;V,`;65M;6]V90!?7V-X85]F:6YA
M;&EZ90!R;61I<@!S=')S='(`<W1R8VAR`'-T<FYC;7``<W1R<F-H<@!B;V]T
M7T1Y;F%,;V%D97(`<&5R;%]C;VYS=')U8W0`86)O<G0`=6YL:6YK`%]?;'-T
M870U,`!P97)L7V9R964`7U]S=&%T-3``7V5X:70`;65M8W!Y`'!E<FQ?9&5S
M=')U8W0`7U]S=&%C:U]C:&M?9F%I;`!03%]D;U]U;F1U;7``4&5R;%]S=E]S
M971P=@!03%]C=7)R96YT7V-O;G1E>'0`<&5R;%]A;&QO8P!C;&]S961I<@!E
M;G9I<F]N`')E861L:6YK`%]?;W!E;F1I<C,P`&UE;7-E=`!097)L7W-A9F5S
M>7-M86QL;V,`7U]S=&%C:U]C:&M?9W5A<F0`4&5R;%]G=E]F971C:'!V`%]?
M<W!R:6YT9E]C:&L`<F5A9`!03%]M96UO<GE?=W)A<`!097)L7W-Y<U]I;FET
M,P!097)L7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7VYE=UA3
M`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-Y<U]T97)M`%]?97)R;F\`7U]D
M97)E9VES=&5R7V9R86UE7VEN9F\`4&5R;%]M9U]S970`;6MD:7(`7U]R96=I
M<W1E<E]F<F%M95]I;F9O`'!E<FQ?<&%R<V4`4&5R;%]N97=84U]F;&%G<P!A
M8V-E<W,`9V5T<&ED`&UE;6-H<@!V9G!R:6YT9@!097)L7V%T9F]R:U]L;V-K
M`&UE;6-M<`!097)L7W-V7W-E='!V;@!P97)L7W)U;@!L<V5E:P!O<&5N`'-P
M<FEN=&8`9V5T=6ED`'-T<FQE;@!?7W1L<U]G971?861D<@!?7W-&`'-T<F-M
M<`!L:6)M+G-O+C``;&EB8W)Y<'0N<V\N,0!L:6)P=&AR96%D+G-O+C$`<'1H
M<F5A9%]A=&9O<FL`<W1R9'5P`&QI8F,N<V\N,3(`7U]P<F]G;F%M90!?7W!S
M7W-T<FEN9W,`7U]G971P=W5I9#4P`%]?<WES8V%L;`!?7W-T<&-P>5]C:&L`
M871E>&ET`%]L:6)C7VEN:70`<W1R=&]K`%]?<F5A9&1I<C,P`%]E;F0`<&%R
M7V-U<G)E;G1?97AE8P!?7V)S<U]S=&%R=%]?`&=E=%]U<V5R;F%M95]F<F]M
M7V=E='!W=6ED`'!A<E]C;&5A;G5P`%]E9&%T80!?7V)S<U]E;F1?7P!P87)?
M8F%S96YA;64`<&%R7V1I<FYA;64`<&%R7VUK=&UP9&ER`'-H85]U<&1A=&4`
M;7E?<&%R7W!L`%]?96YD7U\`<&%R7VEN:71?96YV`'-H85]F:6YA;`!?7V)S
M<U]S=&%R=`!X<U]I;FET`&UA:6X`7U]S=&%R=`!P87)?9FEN9'!R;V<`<&%R
M7W-E='5P7VQI8G!A=&@`<&%R7V5N=E]C;&5A;@!P87)?9&EE`'-H85]I;FET
M`%A37TEN=&5R;F%L<U]005)?0D]/5``O=7-R+W!K9R]L:6(O<&5R;#4O-2XS
M."XP+V5A<FUV-VAF+6YE=&)S9"UT:')E860M;75L=&DO0T]213HO=7-R+W!K
M9R]L:6(``+".`0`7````M(X!`!<```#$D`$`%P```,R0`0`7````U)`!`!<`
M``#DD`$`%P```.B0`0`7````\)`!`!<```#XD`$`%P````B1`0`7````$)$!
M`!<````8D0$`%P```!R1`0`7````()$!`!<````DD0$`%P```#21`0`7````
M.)$!`!<```!`D0$`%P```$21`0`7````2)$!`!<```!,D0$`%P```%"1`0`7
M````6)$!`!<```!<D0$`%P```&21`0`7````R)`!`!4'``#0D`$`%10``-B0
M`0`5(@``W)`!`!$G``#@D`$`$B<``.R0`0`5,@``])`!`!4V``#\D`$`%3P`
M``"1`0`50@``!)$!`!5'```,D0$`%58``!21`0`59@``N(\!`!8#``"\CP$`
M%@0``,"/`0`6!0``Q(\!`!8'``#(CP$`%@@``,R/`0`6"0``T(\!`!8*``#4
MCP$`%@P``-B/`0`6#@``W(\!`!8/``#@CP$`%A```.2/`0`6$@``Z(\!`!86
M``#LCP$`%A<``/"/`0`6&```](\!`!89``#XCP$`%AH``/R/`0`6&P```)`!
M`!8=```$D`$`%AX```B0`0`6'P``#)`!`!8@```0D`$`%B$``!20`0`6(P``
M&)`!`!8H```<D`$`%BD``""0`0`6*@``))`!`!8L```HD`$`%BT``"R0`0`6
M+@``,)`!`!8O```TD`$`%C```#B0`0`6,P``/)`!`!8T``!`D`$`%C4``$20
M`0`6-P``2)`!`!8Y``!,D`$`%CH``%"0`0`6.P``5)`!`!8^``!8D`$`%C\`
M`%R0`0`600``8)`!`!9"``!DD`$`%D,``&B0`0`61```;)`!`!9'``!PD`$`
M%D@``'20`0`620``>)`!`!9+``!\D`$`%D\``("0`0`640``A)`!`!94``"(
MD`$`%E<``(R0`0`66```D)`!`!99``"4D`$`%EL``)B0`0`67```G)`!`!9=
M``"@D`$`%EX``*20`0`67P``J)`!`!9A``"LD`$`%F(``+"0`0`68P``M)`!
M`!9E``"XD`$`%FD``+R0`0`6:@``P)`!`!9K```$X"WE!."?Y0[@C^`(\+[E
M_'L!``#&C^(7RHSB_/N\Y0#&C^(7RHSB]/N\Y0#&C^(7RHSB[/N\Y0#&C^(7
MRHSBY/N\Y0#&C^(7RHSBW/N\Y0#&C^(7RHSBU/N\Y0#&C^(7RHSBS/N\Y0#&
MC^(7RHSBQ/N\Y0#&C^(7RHSBO/N\Y0#&C^(7RHSBM/N\Y0#&C^(7RHSBK/N\
MY0#&C^(7RHSBI/N\Y0#&C^(7RHSBG/N\Y0#&C^(7RHSBE/N\Y0#&C^(7RHSB
MC/N\Y0#&C^(7RHSBA/N\Y0#&C^(7RHSB?/N\Y0#&C^(7RHSB=/N\Y0#&C^(7
MRHSB;/N\Y0#&C^(7RHSB9/N\Y0#&C^(7RHSB7/N\Y0#&C^(7RHSB5/N\Y0#&
MC^(7RHSB3/N\Y0#&C^(7RHSB1/N\Y0#&C^(7RHSB//N\Y0#&C^(7RHSB-/N\
MY0#&C^(7RHSB+/N\Y0#&C^(7RHSB)/N\Y0#&C^(7RHSB'/N\Y0#&C^(7RHSB
M%/N\Y0#&C^(7RHSB#/N\Y0#&C^(7RHSB!/N\Y0#&C^(7RHSB_/J\Y0#&C^(7
MRHSB]/J\Y0#&C^(7RHSB[/J\Y0#&C^(7RHSBY/J\Y0#&C^(7RHSBW/J\Y0#&
MC^(7RHSBU/J\Y0#&C^(7RHSBS/J\Y0#&C^(7RHSBQ/J\Y0#&C^(7RHSBO/J\
MY0#&C^(7RHSBM/J\Y0#&C^(7RHSBK/J\Y0#&C^(7RHSBI/J\Y0#&C^(7RHSB
MG/J\Y0#&C^(7RHSBE/J\Y0#&C^(7RHSBC/J\Y0#&C^(7RHSBA/J\Y0#&C^(7
MRHSB?/J\Y0#&C^(7RHSB=/J\Y0#&C^(7RHSB;/J\Y0#&C^(7RHSB9/J\Y0#&
MC^(7RHSB7/J\Y0#&C^(7RHSB5/J\Y0#&C^(7RHSB3/J\Y0#&C^(7RHSB1/J\
MY0#&C^(7RHSB//J\Y0#&C^(7RHSB-/J\Y0#&C^(7RHSB+/J\Y0#&C^(7RHSB
M)/J\Y0#&C^(7RHSB'/J\Y0#&C^(7RHSB%/J\Y0#&C^(7RHSB#/J\Y0#&C^(7
MRHSB!/J\Y0#&C^(7RHSB_/F\Y0#&C^(7RHSB]/F\Y0#&C^(7RHSB[/F\Y0`0
MH.$"`*#A!]#-XSD``.I,$)_E#<"@X4@@G^4!$(_@1#"?Y3#8+>D#,(_@`B"1
MYP2P3.("`%/A,*B=*`-0X.$"4(7@`U#%XP1`0^(#4(7@!#"TY3/_+^$%`%3A
M^___&C"HG>BP>`$`&`$``*QW`0!T()_E#<"@X7`0G^5P,)_E`B"/X/#8+>D$
ML$SB`4"2YP,PDN<#`%3A\*B=*`0@U.6@`%+C#P``&@A`A.('<(/B!'!'X`=P
MQ^,$<(?@"%`4Y01@H.$`,)7E,_\OX0<`5.$``(7E\*B="`0PUN4(0(3BH`!3
MX_3__PHB___K3'@!`#P!```@`0```%!1XG2!G^4-P*#A"("/X(#8+>D$L$SB
M#-!-XDL```I<(9_E`,"5Y5@QG^4"$)CG`""<Y0!0@>4``%+C`V"8YP@PE>4`
M,(;E.@``"C@QG^4#$)CG`""!Y0`@G.4`,-+E``!3XP4```H!((+B+P!3XP`@
M@04!,-+D``!3X_K__QH``%#C````"O#^_^N+___K^#"?Y0,PF.<``%/C-0``
M"NP@G^7L,)_E`B"8YP,PC^`"`%/A"```*@-PX.$"<(?@`W#'XP1`0^(#<(?@
M!#"TY3/_+^$'`%3A^___&K@`G^4``(_@V?[_Z[`@G^6P,)_E`B"8YP,PC^`"
M`%/A"```*@-PX.$"<(?@`W#'XP1`0^(#<(?@!#"TY3/_+^$$`%?A^___&@`@
MEN4`$)7E!`"5Y=$*`.NJ_O_K3""?Y60PG^4"()CG`S"/X``P@N7+___J5#"?
MY1,@H.,$`*#C`""-Y0,PC^`"(*#C`!"@X_/^_^L!`*#CT/[_ZW[__^O'___J
MR'<!`&0!```X`0``;`$``%P!```H`0``+'8!`##^__]$`0``Y'4!`&1X`0"D
M+0``#<"@X=0PG^7PVRWI`(!0X@2P3.(!<*#A`S"/X"L```J\()_E`C"3YP"0
MD^4``%GC*```"@`PV.4]4%/B`5"@$P``4^,`4*`#``!5XQ$``!H`0)GE``!4
MXPP```H)8*#A!2"@X0@0H.$$`*#AB/[_ZP``4.,"```:!3#4YST`4^,+```*
M!$"VY0``5./S__\:!`"@X?"KG>@(4*#A`3#UY0``4^,]`%,3^___&@A01>#F
M___J`5"%X@E@1N`%0(3@1F&@X0!@A^4$`*#A\*N=Z`A`H.'M___J"4"@X>O_
M_^H,=@$`.`$```W`H.&0,)_E\-@MZ02P3.*(<)_E"-!-XB1`2^('<(_@`%"@
MX0-@E^<`,);E(#`+Y000H.$%`*#AMO__ZP``4.,.```*6#"?Y200&^4#,)?G
M`""3Y0$Q@N`$`)/E``!0XP$!@N?Q__\*!#"#X@0@D^4``%+C!""#Y/O__QKK
M___J("`;Y0`PEN4#`%+A`0``&AS02^+PJ)WH;?[_ZT`!```@=0$`.`$``$0Q
MG^4-P*#A0"&?Y0,PC^#PWRWI!+!,XJS03>("0)/G`&!0X@`PE.4P,`OE`@``
M"@`PUN4``%/C!0``&C`@&^4`,)3E`P!2X3X``!HHT$OB\*^=Z&;^_^L`<%#B
M]O__"NR`G^7,,$OBZ)"?Y=0P"^4(@(_@X#"?Y0F0C^`#,(_@T#`+Y0<`H.'+
M_O_K``!0XR4```H-4(#B"!"@X04`H.'"_O_K``!0X_7__PH)$*#A!0"@X;W^
M_^L``%#C\/__"@8`H.&P_O_K`*"@X04`H.&M_O_K``"*X`(`@.*P_O_K!3"@
MX08@H.'0$!OE`*"@X9S^_^O4$!OE"@"@X1O^_^L!`'#C"@"@X0,```K$,!OE
M#SH#X@$)4^,(```*"O[_ZPH`H.'__?_KU?__Z@<`H.$I_O_K!@"@X>7]_^N^
M___JKO__Z_7__^H7_O_KB'0!`$`!``!\*P``>"L``'@K```-P*#A'#*?Y?#?
M+>D$L$SB%)*?Y1303>(`(-'E"9"/X`%`H.$]`%+C`%"@X0-@F><!0($"!`"@
MX0`PEN4P,`OE>?[_ZS002^(`<*#A!0"@X2[__^L`@%#B/@``"G+^_^L'`%#A
M-0``*L`QG^4T@!OE`Y"9YPB!H.$`,-7E/0!3X@$`H!,``%/C``"@`P``4.,%
M```*!0"@X0$P\.4``%/C/0!3$_O__QH%`$#@`G"'X@"@F>4``(?@8?[_ZP``
M4.,(`(KG5```"@`@F>4!$(7B-``;Y0`PU>4``9+G/0!3XP``4Q,`,,#E!@``
M"@$@@.(!,-'D`@"@X3T`4^,``%,3`3#"Y/G__QH`(*#A/3"@XP`PP.4!,-3D
M``!3XP$PXN7[__\:``"@XS`@&^4`,);E`P!2X3H``!HHT$OB\*^=Z`$P2.(!
M(-3D``!2XP$@X^7[__\:\O__ZM`PG^4#D)GG`""9Y0"@DN4``%KC"!"@`PD`
M``H(,*#A`A"@X0```.H*,*#A!`"QY0&@@^(``%#C^O__&@,P@^(#$:#AD#"?
MY0,PC^```)/E``!0XQ,``!H!`*#A/"`+Y0$0H.,`$(/E'_[_ZP`P4.(X,`OE
M$@``"CP@&^4*@:#A`A"@X0@@H.%=_?_K.#`;Y0`PB>4!((KB`!"@XP(1@^<T
MH`OEG?__Z@(`H.%1_?_K``!0XP`PH.$``(GE"H&@$?/__QH``.#CP/__ZHC]
M_^M``0``&',!`#@!``"8<P$`@#"?Y0W`H.%\()_E`S"/X##8+>D$L$SBH-!-
MX@)`D^>T$$OB`%"@X0`PE.48,`OE8OW_ZP``4.,``*`3!```&JPP&^4/.@/B
M"@I3XP$)4Q,%```*&"`;Y0`PE.4#`%+A!P``&A302^(PJ)WH!0"@X0(0H..T
M_?_K$`]OX:`"H.'S___J8OW_Z_!P`0!``0```#&?Y0W`H.'PWRWI!+!,XO3`
MG^4#,(_@`=M-XD-.2^(,T$WB#("3YP!0H.'<`)_E`6"@X?\C`.,$$*#A`#"8
MY0``C^`P,`OE7/W_ZP"@4.(B``#:N`"?Y0%P2N(``(_@POW_ZRPP2^(',(/@
M!#13Y0``4^,`D)#E$0``"@IPH.$'(*#A+Q"@XP0`H.&0_?_K``!0XPP```H'
M,*#A!""@X040H.$)`*#AE?W_ZS`@&^4`,)CE`P!2X1$``!HHT$OB\*^=Z```
M5^/L__\:!B"@X040H.$)`*#A+/W_Z_+__^HP`)_E``"/X*#]_^L&(*#A!1"@
MX0"0D.4)`*#A(_W_Z^G__^H>_?_K6'`!`$`!``"4)P``0'$!`+AP`0#D,)_E
M#<"@X3#8+>D$L$SBV,"?Y0,PC^`!VTWB04Y+X@C03>(,4)/G"$!$X@`0H.$!
M*Z#C!`"@X0`PE>48,`OEU?S_ZP0`0.`!`$#B`#"$X`0`4^$*``":`"#4YR\`
M4N,'```:`!"@XP(``.H`(-/E+P!2XP(``!H!$$/D!`!3X?G__QHO$*#C!`"@
MX='\_^L``%#C"@``"@0`4.$`,*"#`##`A00`H.%+_?_K&"`;Y0`PE>4#`%+A
M"@``&A302^(PJ)WH&"`;Y0`PE>4#`%+A!```&A@`G^4``(_@%-!+XC!HG>@\
M_?_JWOS_ZSQO`0!``0``T"4``$P@G^4-P*#A2#"?Y4@`G^4"((_@\-@MZ02P
M3.(``(_@`V"2YTS]_^LP4)_E,$"?Y050C^`&(*#A!$"/X`4PH.$$$*#A``"0
MY1S02^+P:)WH]OS_ZDAN`0`D`0``;&\!`&PE``"<)0``7`"?Y0W`H.$PV"WI
M``"/X`C03>($L$SB2$"?Y33]_^L$0(_@`%"@X0``D.79___K-""?Y0``E>4`
M$*#C+#"?Y0(@E.<$$(WE`S"/X"`0G^4`,(WE`1"/X/7\_^L4T$OB,*B=Z!1O
M`0#0;0$`<`$``!`H```T)0````"@XQ[_+^%(,I_E#<"@X40BG^4#,(_@\-\M
MZ1/=3>($L$SB#-!-X@(PD^<`0*#A$WU+XB0"G^4,<$?BX#0+Y0%@H.$`,)/E
M!!!'X@``C^`P,`OEOOW_ZR\0H.,`4*#A!`"@X5S\_^L``%#C"P``"NP!G^4$
M$*#A``"/X'#^_^L$`*#AX#0;Y3`@&^4`,)/E`P!2X6X``!HHT$OB\*^=Z`8`
MH.'6_/_KN!&?Y0$0C^!__/_K`)!0XNS__PJH,9_EJ*&?Y0,PC^#<-`OEH#&?
MY0J@C^"<@9_E`S"/X.0T"^64,9_E"("/X`,PC^#8-`OE`##9Y0``4^,\```*
M``!5XP0```H)$*#A!0"@X>#\_^L``%#C+0``"@D`H.'3_/_K`1!`X@!@H.$!
M,(G@`P!9X0T``"H!$-GG+P!1XPH``!H``*#C`@``Z@`@T^4O`%+C`@``&@$`
M0^0#`%GA^?__&@D`H.'!_/_K`&"@X00`H.&^_/_K!@"`X`$`@.(!"U#CNO__
M*M@T&^5#;DOB`2N@XP`0H.,(0(WE!@"@X00PC>4*,*#A`)"-Y5G\_^L'$*#A
M!@"@X2;\_^L``%#C`P``&L0T&^4/.@/B`@E3XQ$```H($*#A``"@XS7\_^L`
MD%#BHO__"@`PV>4``%/CPO__&@``5>,3```*W!0;Y04`H.&C_/_K``!0XP%@
MH!/<E!L5[O__"M3__^H!$*#C!@"@X6C\_^L``%#CZ/__&DP`G^4&$*#A``"/
MX`'^_^L&`*#A;_S_ZX[__^H!8*#CY)0;Y<7__^H-_/_K9&T!`$`!``#<)```
MO"0``)@D```,)```>"0``/@C``!@)```*"<````C```-P*#A+Q"@XS#8+>D$
ML$SB`$"@X=C[_^L``%#C`4"`$@0`H.$4T$OB,&B=Z%/\_^H-P*#A,-@MZ0!`
M4.($L$SB"@``"@`PU.4``%/C!P``"F7\_^L!`(#B`0M0XP@``(H$`*#A%-!+
MXC!HG>C,_O_J%`"?Y0``C^`4T$OB,&B=Z#[\_^H``*#C,*B=Z-@A``!L(9_E
M#<"@X6@QG^4"((_@9`&?Y7#8+>D$L$SB#-!-X@-0DN<``(_@4&&?Y21`2^(`
M,)7E!F"/X"`P"^4Y_?_K/`&?Y0``C^`V_?_K-`&?Y0``C^`S_?_K+`&?Y0``
MC^`P_?_K)`&?Y0``C^`M_?_K'`&?Y0``C^`J_?_K%`&?Y0``C^`G_?_K#`&?
MY0``C^`D_?_K!@"@X2+]_^O\`)_E``"/X!_]_^OT`)_E``"/X!S]_^OL`)_E
M!!"@X0``C^#>_/_K`!!0X@$```H&`*#AEOW_Z]``G^4$$*#A``"/X-;\_^L`
M$%#B`@``"KP`G^4``(_@C?W_Z[0`G^4$$*#A``"/X,W\_^L`$%#B#0``"J``
MG^4``(_@A/W_ZY@0G^68`)_E`1"/X```C^!__?_K("`;Y0`PE>4#`%+A"P``
M&AC02^)PJ)WH=`"?Y000H.$``(_@N?S_ZP`04.+N__\*8`"?Y0``C^!P_?_K
MZO__ZH'[_^M8:@$`0`$``!@B``!8(@``!"(````B````(@``_"$````B``"4
M(0``]"$``/@A``!T(0``Z"$``-PA``#<(0``V"$````A``#8(0``/"$``)@A
M```<(0``;#"?Y0W`H.%H()_E`S"/X&0`G^40V"WI!+!,X@S03>("0)/G'!!+
MX@``C^``,)3E&#`+Y8[\_^L``%#C!0``"@``T.4``%#C,`!0$P$`H`,``*`3
M`0`@XA@@&^4`,)3E`P!2X0$``!H0T$OB$*B=Z$[[_^N,:`$`0`$``(P@```-
MP*#A#P`MZ40PG^4`V"WI%+!,XCS`G^4#,(_@"-!-XC0`G^4(X(OB#,"3YQ3@
M"^4.(*#A!!";Y0#`G.40P`OE``"3Y[``@.*/^__K_P"@X_3Z_^L`:`$`0`$`
M`&@!``#$$9_E#<"@X?#?+>D$L$SBN,&?Y0$0C^`!V$WB`N"@XR303>(,$)'G
M`<A+XD3`3.(`(*#C`#"@XP"`H.$`$(SE`'"@XP#@C>4`$)'E,!`+Y83[_^L!
M0%#B`%#!XL5OH.$&`*#AQA^@X09@).`!,"?@`"!6X')@_^8`(";@`"!2X`$P
MP^`"0%3@`U#%X```5.,`,-7B!&"@X05PH.%!``"Z+%&?Y0$H2^(!2$OB)#&?
MY4`@0N((D*#C!5"/X`&00.,X0$3B`S"/X``P@N4`$*#C!B"@X0<PH.$`$(WE
M"`"@X6#[_^L`,.#C`"#@XP,`4>$"`%`!+@``"@D@H.$$$*#A"`"@X17[_^L!
M`'#C&@``"@<`4.,;``":"`!`X@"@E.`#```Z%P``Z@&@2N($`%KA%```.@@@
MH.,%$*#A"@"@X3S[_^L``%#C]O__&@1`2N`$`);@Q!^GX`$X2^(P(!OE1#!#
MX@`PD^4`,)/E`P!2X10``!HHT$OB\*^=Z%@`G^4``(_@A?__ZP%H5N(`(*#C
M`'#'XO\O3^,`,.#C`P!7X0(`5@'(__\:``#@XP`0X./H___J`3A+XD`P0^(`
M`)/E=O__Z\O__^K`^O_KI&<!`$`!``!\:`$`D!\``.0>```-P*#A`-@MZ02P
M3.(I^__K(OO_ZP``4.,``)`5`*B=Z-0PG^4-P*#AT""?Y0,PC^#PV2WI!+!,
MXA303>("0)/G`%"@X;A@G^4L$$OB`#"4Y09@C^`&`*#A*#`+Y=3[_^L%$*#A
M`'!0XAD```H`,-?E``!3XQ8```IL^O_K``!0XQ8``!H%`*#A$/O_ZP"`H.$'
M`*#A#?O_ZP``B.`"`(#B$/O_ZUPPG^5<$)_E!2"@X0!PC>4#,(_@`1"/X`"`
MH.'Y^O_K"!"@X08`H.%T_/_K`@``ZC0`G^4``(_@</S_ZR@@&^4`,)3E`P!2
MX0$``!H@T$OB\*F=Z'SZ_^NL90$`0`$``$`>``#P'```\!P``+@=```-P*#A
M(#:?Y?#?+>D$L$SB&,:?Y44?2^)+WTWB#,"/X#@!"^4,((SB0!$+Y0'@H.'\
MA9_E!P"2Z`B`C^`8<(SB2V]+X@.0F.<PP(SB$DY+XA->2^('`(;H#P"WZ#R1
M"^4`D)GE#P"NZ`,`E^@PD`OE`P".Z`<`G.@'`(3H!1"@X;`%G^4``(_@A/O_
MZP!P4.("```*`##7Y0``4^.+```:D?__ZP"@4.*-```*"@"@X<'Z_^N``*#A
M`0"`XL3Z_^L`(-KE``!2XP"0H.$)```*9'6?Y0E`H.$'<(_@!`"@X0<0H.&K
M^O_K`2#ZY0)`A.(``%+C^/__&A0!&^4``%#C$@``"D!!&^4"``#J!`"TY0``
M4.,-```*!1"@X5_[_^L`<%#B^/__"@`PU^4``%/C]?__"J/\_^L``%#C\O__
M"@<`H.&!^O_K`*!0XA<``!H`<*#C+#!+X@<Q@^``01/E``!4XPH```H`,-3E
M``!3XP<```H$`*#A`7"'XI'\_^L``%#C!```&@=!EN<``%3C]/__&@"@H.,$
M``#J!`"@X6KZ_^L``%#CZ?__"@"@H.$*`*#A@/K_ZP!`H.$)`*#A??K_ZP``
MA.`!2X#B!$"$X@0`H.%^^O_K8!2?Y6`TG^4*(*#A`1"/X``0C>54%)_E`S"/
MX`20C>4!$(_@`'"@X63Z_^L'`*#A!QV@XS3Z_^L!`'#C&@``"OP02^('`*#A
MV/G_ZP!@4.(#```:]#`;Y0\Z`^(!"5/C0P``"@@$G^4',*#A."$;Y0!`H./\
M$Y_E``"8YP`@DN4!$(_@L`"`XM3Y_^L\,1OE!`"@X3`@&^4`,)/E`P!2X>H`
M`!HHT$OB\*^=Z`WZ_^L`,)#E$0!3X^#__PHX,1OE`$"3Y0?Z_^NDPY_E!S"@
MX:03G^4$(*#A`$"@XPS@F.<!$(_@`,"0Y;``CN(`P(WENOG_Z^3__^H-___K
M!P"@X1SZ_^L`0*#AW___Z@IPH.$'D83@!)!)X@0`N>4``%#C#```"@40H.$!
M<(?BY?K_ZP`P4.+W__\*`##3Y0``4^/T__\*"_K_ZP``4./O__\*`*"@X5[_
M_^H-`*#C'*.?Y27Z_^M3(*#C"J"/X`"0H.%@___JX)`;Y1/Z_^L``%GAM___
M&O0P&^53,.CG!PU3X[/__QH$`*#A%_K_ZP40H.$`0*#AV`*?Y0``C^#%^O_K
M`!!0XE(```HX,1OE``"3Y>W\_^L`4%#B30``"@4`H.$#^O_K`P!0XP"`H.$,
M``":H!*?Y00`0.(``(7@`1"/X`3Z_^L``%#C!0``&@0`6.."```*"("%X`4P
M6.4O`%/C?@``"@[^_^L`H%#B!```&@4`H.$*$*#AWOG_ZP!04.(V```:4!*?
MY5`"G^4!$(_@3)*?Y0``C^!(@I_E6?O_ZT12G^6[^?_K0!*?Y4`RG^4'(*#A
M`1"/X`00C>4T$I_E`S"/X`F0C^`(@(_@`1"/X`50C^```(WE!`"@X<OY_^L-
M``#JD_G_ZP`PD.41`%/C#@``&J?Y_^L!8(;B"%"-Y0DPH.$$8(WE!R"@X0@0
MH.$``(WE!`"@X;SY_^L'':#C!`"@X8SY_^L!`'#C[/__"@<`H.$E^?_KO`&?
MY000H.$``(_@+_O_ZP0`H.&,_O_K8?__ZC@Q&^4`4)/EKO__Z@?^_^L``%#C
M`("@X0`PT>(!D*#APO__N@H@4.)D,$OB`*"-Y04`H.$X,0OE`##!XI7Y_^LX
M$1OE!B"@XP4`H.%/^?_K!@!0XP(```I,`9_E``"/X-K]_^M$,9_E9"`;Y0,P
MC^`,$(/B##"3Y0,`4N&K__\:.#$;Y;0@T^&T,-'A`P!2X:;__QHR(%CB7&!+
MX@`PR>(`$*#C!0"@X0`0C>5Y^?_K!0"@X080H.$H(*#C,_G_ZR@`4.,"```*
MY`"?Y0``C^"^_?_KW!"?Y0<@H.'8,)_E!`"@X0$0C^`$$(WES!"?Y0,PC^``
M8(WE`,"@XP$0C^`TP$OE;/G_Z[/__^HX,1OE!("3Y0``6.-\__\*"`"@X6[Y
M_^L#`%#C>/__FI`0G^4$`$#B``"(X`$0C^!P^?_K``!0XPA0H`%P___JZ_C_
MZT`!```D9@$`C&0!`/`;``"\'```Q!L``&P=``"D&P``:`$``)0;``#X&@``
M3!H``,`:``"$&@``2!D``,08```0&P``-!H``-0:``#P&@``%!L``"`:``"L
M%P``(!D``,`6``"P&```;!D``)`9``",&```/!@``#PBG^4-P*#A.#*?Y0(@
MC^`T`I_E\-DMZ02P3.(,T$WB`V"2YP``C^`L4$OB`#"6Y2@P"^4Z^?_K!1"@
MX0`PD.4(`I_E9"#3Y0``C^!E(,/EZ?G_ZP``4.,"```*`##0Y3$`4^->```*
MT_S_Z^`!G^7@09_E``"/X"GY_^L$0(_@`S"@XP$@H.,$$*#A`'"@X0``D.7%
M^/_K`$!0X@H```H,,)3EL"&?Y0``E^4`$)/E`B"/X*+X_^L,,)3E`!"3Y0@P
MD>4!!1/C40``&HP!G^6,09_E``"/X!'Y_^L$0(_@`S"@XP$@H.,$$*#A`'"@
MX0``D.6M^/_K`$!0X@D```I@`9_E!1"@X0``C^"Z^?_K`"!0XC8```H,,)3E
M``"7Y0`0D^6&^/_K/`&?Y3R!G^4``(_@^OC_ZS01G^4!(*#C"("/X`$0C^``
M<)#E`$"@X0<`H.&A^/_K&"&?Y0(@C^``$*#A!P"@X77X_^L`,)3E!`&?Y0`@
MH.,%$*#A``"/X&4@P^6<^?_K``!0XP@`B.4+```*!QV@XZCX_^L!,(#B$0!0
MXP$`4Q,=``"**"`;Y0`PEN4#`%+A&```&B#02^+PJ9WH!`"8Y>/]_^L``%#C
M"`"(Y>[__QJ@`)_E``"/X('X_^L!,-#E``!3XY[__PJ<___JB#"?Y0P@E.4#
M,(_@!#"3Y0``DN4`$)/EZ/K_Z\3__^H``)?EA?C_ZZK__^I$^/_K7""?Y0`P
MH.%8`)_E`B"/X```C^`&`)+I`!"1Y6GX_^L47@$`0`$``"Q?`0#8%0``W%X!
M`'@7``!(%P``?%X!`"07``#4%```(%X!`.1>`0#`%@``P!8``%04``!(%@``
M*%X!`/1=`0`4%@``#<"@X3#8+>D$L$SB`$"@X2W\_^L@_/_K`%"@X;7\_^L`
M`%#C``!4$S"HG0@`,-3E``!3XS"HG0@D$)_E!0"@X00@H.,!$(_@[/?_ZP``
M4.,PJ)T8!`"@X1302^(P:)WHI?G_ZC`4``#T.Y_E#<"@X?#?+>D#,(_@Z.N?
MY02P3.)5WTWB%TY+XAP@@.(.,)/G7,"`X@00H.%X,0OE`#"3Y3`P"^4$,)+D
M`@!<X3,_O^8$,('D^O__&OQ`A.)=[TOB#B"@X000ON4X,)+E),"2Y00`7N$,
M()+E##`CX`(P(^`!,"/@XS^@X4`PCN7S__\:<'$;Y9DY!^,$$)#E@CI%XQ#@
MD.4#<(?@"%"0Y:$K#N,,0)#E#G"'X`!@D.5AD:#A!."0Y000)>!LP1OEV2Y&
MXPX0`>!F@:#A">`EX`00(>!HH1OEYGV'X`%PA^`#P(S@"!`IX`;@#N`'$`'@
M!,",X`.@BN`%X"[@#.".X`6@BN`)P"'@Y^V.X`K`C.!G<:#A9*$;Y0<0*.`.
M$`'@[LV,X`.@BN`($"'@"9"*X&[AH.$)$('@8)$;Y0Z@)^#L'8'@#*`*X`.0
MB>!LP:#A")")X`>`*N!<H1OE"8"(X`R0+N`#H(K@`9`)X.&-B.`.D"G@81&@
MX0=PBN!8H1OE!W")X`&0+.#H?8?@`Z"*X`B0">`,D"G@#N"*X&B!H.$.X(G@
M5)$;Y0B@(>`'H`K@Y^V.X`.0B>!G<:#A#)")X`'`*N!0H1OE"<",X`>0*.#N
MS8S@`Z"*X`Z0">`!$(K@"*`IX&[AH.$!$(K@3*$;Y0Z0)^`,D`G@[!V!X`.@
MBN`'D"G@"("*X&S!H.$(D(G@2($;Y0R@+N#AG8G@`:`*X`.`B.!A$:#A!X"(
MX`YP*N!$H1OE"("'X`%P+.`#H(K@"7`'X.F-B.`.X(K@:9&@X4"A&^4,<"?@
M#G"'X`G@(>`#H(K@".`.X`S`BN`!X"[@Z'V'X`S@CN!H@:#A/,$;Y0B@*>#G
M[8[@!Z`*X`/`C.!G<:#A`<",X`D0*N`XH1OE#,"!X`<0*.`#H(K@#A`!X`F0
MBN`(H"'@[LV,X`F0BN!NX:#A-*$;Y0X0)^#LG8G@`Z"*X`P0`>`'$"'@;,&@
MX0B`BN`PH1OE"("!X`P0+N`#H(K@"1`!X.F-B.`.$"'@:9&@X0=PBN`LH1OE
M!W"!X`D0+.#H?8?@`Z"*X`@0`>`,$"'@:(&@X0[@BN`HH1OE#N"!X`@0*>`#
MH(K@!Q`!X`R@BN`)$"'@Y^V.X`H0@>!G<:#A)*$;Y0?`*.#N'8'@`S"*X`[`
M#.`@H1OE",`LX&[AH.$),(/@`S",X`*0BN`.P"?@'*$;Y>$]@^`(D(G@`<`L
MX&&!H.$($"[@#,")X`*0BN`8H1OEX\V,X`=PB>`#$"'@8S&@X0*0BN`!$(?@
M%*$;Y0-P*.#L'8'@#N")X`QP)^!LP:#A`I"*X`=PCN`0H1OE#.`CX.%]A^`(
M@(G@`>`NX&$1H.$!D"S@#N"(X`*`BN`,H1OEY^V.X`.`B.`',"G@9W&@X0>0
M(>`#,(C@`H"*X`BA&^7N/8/@#("(X`[`*>!NX:#A#I`GX`S`B.`"@(K@!*$;
MY>/-C.`!@(C@`Q`IX&,QH.$#D"[@`1"(X`*`BN``H1OE[!V!X`>`B.`,<"G@
M;,&@X0R0(^`'<(C@`H"*X/R@&^7A?8?@#H"(X`'@*>!A$:#A`9`LX`[@B.`"
M@(K@^*`;Y>?MCN`#@(C@!S`IX&=QH.$'D"'@`S"(X`*`BN#TH!OE[CV#X`R`
MB.`.P"G@;N&@X0Z0)^`,P(C@`H"*X/"@&^7CS8S@`8"(X`,0*>!C,:#A`Y`N
MX`$0B.`"@(K@[*`;Y>P=@>`'@(C@#'`IX&S!H.$,D"/@!W"(X`*`BN#HH!OE
MX7V'X`Z`B.`!X"G@81&@X0&0+.`.X(C@`H"*X.2@&^7G[8[@`X"(X`<P*>!G
M<:#A!Y`AX`,PB.`"@(K@X*`;Y>X]@^`,@(C@#L`IX&[AH.$.D"?@#,"(X`*`
MBN#<H!OEX\V,X`&`B.`#$"G@8S&@X0*0BN`!$(C@V*`;Y0.`+N#L'8'@!W")
MX`R`*.!LP:#A`I"*X`B`A^#4H!OE#'`CX.&-B.`!<"?@#N")X&$1H.$'X([@
M`J"*X-"0&^4!("S@:'&@X>CMCN`#H(K@`H`HX-P\"^,;/TCC!R"!X0B@BN`#
MD(G@;H&@X0X@`N`,P(G@[NV*X,R0&^4'H`'@"J""X0@@A^$,P(K@#B`"X`.@
MB>`(D`?@[LV,X`$0BN!NX:#A"2""X<B0&^4!((+@#A"(X0Z@".`#D(G@#!`!
MX`=PB>`*$('A["V"X`<0@>!LP:#AQ'`;Y0R0CN'B'8'@`Z"'X`*0">!B<:#A
M#"`.X`(@B>'`D!OE"*"*X`>`C.$*((+@`8`(X`.@B>`'D`S@X2V"X`F`B.%A
M$:#A#N"*X+R0&^4.X(C@`8"'X0&@!^`"@`C@`Y")X.+MCN`,D(G@8B&@X0J@
MB.&X@!OE`L"!X0F@BN`.P`S@`Y"(X&Z!H.'N[8K@`J`!X`>0B>`*P(SA"<",
MX+20&^4(<(+A[LV,X`.@B>`.<`?@")`"X&[AH.$)<(?A`1"*X+"0&^4!$(?@
M#G"(X0Z@".`,<`?@`Y")X.P=@>`"D(G@;,&@X0J@A^&L<!OE#"".X0F@BN`!
M(`+@`Y"'X&%QH.'A'8K@#*`.X`B0B>`*((+A"2""X*B0&^4'@(SAX2V"X`.@
MB>`!@`C@!Y`,X&$1H.$)@(CA#N"*X*20&^4.X(C@`8"'X0&@!^`"@`C@`Y")
MX.+MCN`,D(G@8B&@X0J@B.&@@!OE`L"!X0F@BN`.P`S@`Y"(X&Z!H.'N[8K@
M`J`!X`>0B>`*P(SA"<",X)R0&^4(<(+A[LV,X`.@B>`.<`?@")`"X&[AH.$)
M<(?A`1"*X)B0&^4!$(?@#G"(X0Z@".`,<`?@`Y")X.P=@>`"D(G@;,&@X0J@
MA^&4<!OE#"".X0F@BN`!(`+@`Y"'X&%QH.'A'8K@#*`.X`B0B>`*((+A"2""
MX)"0&^4'@(SAX2V"X`.@B>`!@`C@!Y`,X&$1H.$)@(CA#N"*X(R0&^4.X(C@
M`8"'X0&@!^`"@`C@`Y")X`J@B.&(@!OEXNV.X`R0B>!B(:#A":"*X`+`@>$#
MD(C@#L`,X&Z!H.$'<(G@[NV*X(20&^4"H`'@"J",X0C`@N$'<(K@`S")X`[`
M#.`(D`+@@*`;Y>Y]A^`!,(/@;N&@X0G`C.'6$0SC8AI,XP/`C.`!D(K@#C`H
MX'R@&^7GS8S@`B")X`<P(^!G<:#A`9"*X`,P@N!XH!OE!R`NX.P]@^`(D(G@
M#(`BX&PAH.$(P(G@`I`GX`&`BN!TH!OEX\V,X`Z`B.`#X"G@8S&@X0&0BN`.
MX(C@<*`;Y0.`(N#L[8[@!Y")X`R`*.!L<:#A",")X`>0(^`!@(K@;*`;Y>[-
MC.`"@(C@#B`IX&[AH.$"((C@#I`GX`&`BN!HH!OE["V"X`.`B.`,,"G@;,&@
MX0,PB.`,D"[@`8"*X&2@&^7B/8/@!X"(X`)P*>!B(:#A!W"(X`*0+.`!@(K@
M8*`;Y>-]A^`.@(C@`^`IX&,QH.$.X(C@`Y`BX`&`BN!<H!OEY^V.X`R`B.`'
MP"G@9W&@X0S`B.`'D"/@`8"*X%B@&^7NS8S@`H"(X`X@*>!NX:#A`B"(X`Z0
M)^`!@(K@5*`;Y>PM@N`#@(C@##`IX&S!H.$#,(C@#)`NX`&`BN!0H!OEXCV#
MX`>`B.`"<"G@8B&@X0=PB.`"D"S@`8"*X$R@&^7C?8?@#H"(X`/@*>!C,:#A
M#N"(X`.0(N`!@(K@2*`;Y>?MCN`,@(C@!\`IX&=QH.$,P(C@!Y`CX`&`BN!$
MH!OE[LV,X`*`B.`.("G@;N&@X0(@B.`.D"?@`8"*X$"@&^7L+8+@`X"(X`PP
M*>!LP:#A`S"(X`R0+N`!@(K@/*`;Y>(]@^`'@(C@`G`IX&(AH.$'<(C@`I`L
MX`&`BN`XH!OE#H"(X`/@*>#C?8?@#N"(X`&`BN!C,:#A#,"(X#2`&^4#D"+@
MY^V.X`>0*>`!$(C@9W&@X0>`(^`)P(S@!A"!X.[-C.`"(('@#H`HX`B`@N`0
M$)#E["V(X``@@.5X(1OE`S"!X#"0&^5NX87@!!"0Y0=PA.``()+E#,"!X`C@
M@.4"`%GA$#"`Y03`@.4,<(#E`0``&BC02^+PKYWH$/7_ZQQ;`0!``0``#<"@
MX6``H.,`V"WI!+!,XH?U_^L!$P+CB2L*XT471N/-+T[C`!"`Y?X<#>,$((#E
MNAA)XW8D!>,($(#E,B!!X_`1#N,,((#ETA-,XP`@H.,0$(#E%""`Y1@@@.5<
M((#E`*B=Z`W`H.'PVRWI`H"@X10PD.6"(:#A`%"@X0%`H.$",)/@&""0Y5P`
MD.4`$*#C`1"@(P``4>,!(((2``!0XZ@N@N`$L$SB%#"%Y1R0A>(8((7E#P``
M"D!@8.($$*#A!@!8X0``B>`(8*"Q!B"@X=/T_^M<,)7E`S"&X%PPA>5``%/C
M\*N=&`4`H.$&@$C@!D"$X,#\_^L_`%CC&```VD"`2.(H8Z#A`7"&X@=SA.!`
M((3B!!"@X0DPH.$`0)'E$!"!X@S@$>40,(/B",`1Y00`$>4"`%'A$$`#Y0S@
M`^4(P`/E!``#Y?/__QH%`*#A`4"@X:C\_^L'`%3AZ___&@:#2.`$$*#A"0"@
MX0@@H.&K]/_K7("%Y?"KG>@-P*#A\-LMZ1R`@>(48)'E`4"@X1APD>4`4*#A
MUC'EYW\0X.,!((/B!+!,XC@`4N,#$,CG`@"(X$D``-I`(&+B`!"@X[7T_^L$
M`*#AB_S_ZP@`H.$X(*#C`!"@XZ_T_^M7<,3E)RR@X5M@Q.4G.*#A5"#$Y00`
MH.$F+*#A53#$Y2=TH.$F.*#A5G#$Y29DH.%9,,3E6"#$Y5I@Q.5W_/_K`S#4
MY00`H.$`,,7ELC#4X0$PQ>4`,)3E(S2@X0(PQ>4`,)3E`S#%Y0<PU.4$,,7E
MMC#4X04PQ>4$,)3E(S2@X08PQ>4$,)3E!S#%Y0LPU.4(,,7ENC#4X0DPQ>4(
M,)3E(S2@X0HPQ>4(,)3E"S#%Y0\PU.4,,,7EOC#4X0TPQ>4,,)3E(S2@X0XP
MQ>4,,)3E#S#%Y1,PU.40,,7ELC'4X1$PQ>40,)3E(S2@X1(PQ>40,)3E$S#%
MY2302^+P:YWH-?3_ZC@@8N(`$*#C:_3_Z[K__^IH,)_E#<"@X3#8+>D#,(_@
M7$"?Y02P3.(D(-/E!$"/X```4N,PJ)T82""?Y0$0H.,D$,/E`C"4YP``4^,"
M```*-#"?Y0,`G^<&]/_K+#"?Y0,PE.<``%/C,*B=""``G^4``(_@%-!+XC!H
MG>AR]/_J!$X!`!A,`0`<`0``:$T!`%0!``!P10``/!"?Y3PPG^4!$(_@`S"/
MX``@T>4``%+C'O\O$2@@G^4!`*#C``#!Y0(PD^<``%/C'O\O`10`G^4$$('B
M``"/X&3T_^J`30$`H$L!`%@!```,10``#<"@X30RG^7PV"WI!+!,XBQBG^4@
MT$WB*``+Y09@C^`L$`OE,"`+Y2@`2^(#4);G+!!+XC`@2^(`,)7E(#`+Y3'T
M_^O\(9_E_#&?Y0(@EN<#`);G`A"@X3?T_^OL,9_E`S"6YP!`T^4``%3C3@``
M"MP!G^4``(_@=_3_ZRAP&^4$$(?B`W"'X@<!<>,`()#E1C/2Y0,P@^-&,\+E
M5P``B@$!H.$,]/_KJ"&?Y2Q`&^4"((_@H!&?Y0$0C^``,*#A``"4Y00P@N60
M(9_E\`##X2@`&^4"$);G`0!0XX`AG^4`$)'E`B"/X!``H-,,((/E"!"#Y0@`
M`-H$$(3B#,"#X@!!A.`$X)'D!`!1X03@K.7[__\:`P"`X@`!H.%$09_E`!"@
MXP`0C>4'(*#A`!"#YP1`C^`P$9_E#`"4Y0$0C^`2]/_K``!0XRD```H<09_E
M)&!+X@1`C^`,`)3EP//_ZP80H.$`<*#A!`&?Y0``C^#O]/_K``!0XQ@```KT
M,)_E`S"/X`P`D^6F\__K[?/_ZR`@&^4`,)7E!P"@X0,`4N$C```:'-!+XO"H
MG>BU\__KQ#"?Y0,PC^```%#C#`"#Y1P```J+\__KL`"?Y0``C^`A]/_K`#"0
MY>9%P^6C___J"`"4Y0``4.,)```*=?O_Z^'__^H,`)3E__/_Z]+__^I\,)_E
M?`"?Y0,0EN<``(_@P_/_ZW``G^4&$*#A``"/X,/T_^L``%#C"`"$Y=+__PKM
M___JC?/_ZP$`H.-)\__K0`$``#Q+`0!0`0``8`$``"P!```43`$`K$P!``P%
M``!,`0``Y`0``"Q,`0`DW/__"$P!`/P!``#<2P$`J$L!`+Q*`0!(`0``^`(`
M`.P```!P<U]S=')I;F=S(&UI<W-I;F<*`'!E<FQX<VDN8P````!#04-(10``
M+@```"XN```E<R\E<P```"]P<F]C+V-U<G!R;V,O97AE````1'EN84QO861E
M<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4`````%!!
M4E]414U0`````%!!4E]04D]'3D%-10`````Z````)7,E<R5S``!015),-4Q)
M0@````!015),3$E"`%!%4DPU3U!4`````%!%4DQ)3P``4$%27TE.251)04Q)
M6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!3@```%!!4E]$14)51P```%!!4E]#
M04-(10```%!!4E]'3$]"04Q?1$5"54<`````4$%27T=,3T)!3%]435!$25(`
M``!005)?5$U01$E2``!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!
M3@`````Q````;'-E96L@9F%I;&5D`````')E860@9F%I;&5D`$Q$7TQ)0E)!
M4EE?4$%42`!365-414T``"4P,G@`````)7,E<R5S)7,`````<&%R+0`````E
M<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D
M("AE<G)N;STE:2D*```E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@
M=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A
M=&EO;BD*``!0051(`````'!A<FP`````+G!A<@````!S:&]R="!R96%D```E
M<R5S8V%C:&4M)7,E<P``)7,E<W1E;7`M)74E<P```"5S)7-T96UP+25U+25U
M)7,`````&````'!E<FP`````,````%!!4CHZ4&%C:V5R.CI615)324].````
M`#$N,#4Y````56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD`````
M)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S
M(&9A:6QE9"`H97)R;F\])6DI"@`````M90``+2T``%5315(`````55-%4DY!
M344`````5$5-4$1)4@!435``+W1M<"\```!E=F%L("=E>&5C("]U<W(O8FEN
M+W!E<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U
M;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D4$%27TU!
M1TE#+"`D1DE,15]O9F9S971?<VEZ92P@)&-A8VAE7VYA;65?<VEZ92D["D)%
M1TE.('L*)%!!4E]-04=)0R`](")<;E!!4BYP;5QN(CL*)$9)3$5?;V9F<V5T
M7W-I>F4@/2`T.R`@(",@<&%C:R@B3B(I"B1C86-H95]N86UE7W-I>F4@/2`T
M,#L*)%!+6DE07TU!1TE#(#T@(E!+7#`P,UPP,#0B.PI]"G-U8B!F:6YD7W!A
M<E]M86=I8PI["FUY("@D9F@I(#T@0%\["FUY("1C:'5N:U]S:7IE(#T@-C0@
M*B`Q,#(T.PIM>2`D8G5F.PIM>2`D<VEZ92`]("US("1F:#L*;7D@)'!O<R`]
M("@D<VEZ92TQ*2`M("@D<VEZ92TQ*2`E("1C:'5N:U]S:7IE.R`@("`@(",@
M3D]413H@)'!O<R!I<R!A(&UU;'1I<&QE(&]F("1C:'5N:U]S:7IE"G=H:6QE
M("@D<&]S(#X](#`I('L*<V5E:R`D9F@L("1P;W,L(#`["G)E860@)&9H+"`D
M8G5F+"`D8VAU;FM?<VEZ92`K(&QE;F=T:"@D4$%27TU!1TE#*3L*:68@*"AM
M>2`D:2`](')I;F1E>"@D8G5F+"`D4$%27TU!1TE#*2D@/CT@,"D@>PIR971U
M<FX@)'!O<R`K("1I.PI]"B1P;W,@+3T@)&-H=6YK7W-I>F4["GT*<F5T=7)N
M("TQ.PI]"FUY("@D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4L("5-
M;V1U;&5#86-H92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q
M=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U
M:7)E($9I;&4Z.E-P96,["FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ
M9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S*'%Q6U)E;6]V:6YG(&9I;&5S(&EN
M("(D<&%R7W1E;7`B72D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H
M("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D
M<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R
M)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T
M;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P
M9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["FUY("1F
M:6QE;F%M92`]("1T;7`M/F9I;&5N86UE.PIP<FEN="`D=&UP(#P\(BXN+B([
M"G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T
M96UP)PII9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*
M<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R1F:6QE;F%M92<*
M+BXN"F-L;W-E("1T;7`["F-H;6]D(#`W,#`L("1F:6QE;F%M93L*;7D@)&-M
M9"`]("(D9FEL96YA;64@/B]D978O;G5L;"`R/B8Q("8B.PIS>7-T96TH)&-M
M9"D["F]U=',H<7%;4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R
M9F]R;2!C;&5A;G5P.B`D9FEL96YA;65=*3L*?0I]('T*0D5'24X@>PI);G1E
M<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2
M.CI"3T]4.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D<75I970@/2`A
M)$5.5GM005)?1$5"54=].PIM>2`E<WES(#T@*`IP871H7W-E<"`@("`]/B`H
M)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@("`@/3X@
M*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G
M*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG
M(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PIO=71S*'%Q6UPD<')O9VYA
M;64@/2`B)'!R;V=N86UE(ETI.PI?<V5T7W!A<E]T96UP*"D["F]U=',H<7%;
M7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!](ETI.PIM>2`H)'-T
M87)T7W!O<RP@)'-T87)T7V]F7T9)3$5?<V5C=&EO;BD["DU!1TE#.B!["FQO
M8V%L("1324=[7U]705).7U]](#T@<W5B('M].PIU;FQE<W,@*&]P96X@7T9(
M+"`G/#IR87<G+"`D<')O9VYA;64I('L*;W5T<RAQ<5M#86XG="!R96%D(&9R
M;VT@9FEL92`B)'!R;V=N86UE(ETI.R`@(R!D;VXG="!U<V4@)"$@:&5R92!A
M<R!I="!R97%U:7)E<R!%<G)N;RYP;0IL87-T($U!1TE#.PI]"FUY("1M86=I
M8U]P;W,@/2!F:6YD7W!A<E]M86=I8R@J7T9(*3L*:68@*"1M86=I8U]P;W,@
M/"`P*2!["F]U=',H<7%;0V%N)W0@9FEN9"!M86=I8R!S=')I;F<@(B1005)?
M34%'24,B(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0SL*?0IO
M=71S*")&;W5N9"!005(@;6%G:6,@870@<&]S:71I;VX@)&UA9VEC7W!O<R(I
M.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE("T@
M;&5N9W1H*")<,$-!0TA%(BDL(#`["G)E860@7T9(+"`D8G5F+"!L96YG=&@H
M(EPP0T%#2$4B*3L*:68@*"1B=68@;F4@(EPP0T%#2$4B("8F("1B=68@;F4@
M(EPP0TQ%04XB*2!["F]U=',H(DYO(&-A8VAE(&UA<FME<B!F;W5N9"(I.PIL
M87-T($U!1TE#.PI]"F]U=',H<7%;0V%C:&4@;6%R:V5R("(D8G5F(B!F;W5N
M9%TI.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE
M+"`P.PIR96%D(%]&2"P@)&)U9BP@)$9)3$5?;V9F<V5T7W-I>F4["FUY("1O
M9F9S970@/2!U;G!A8VLH(DXB+"`D8G5F*3L*;W5T<R@B3V9F<V5T(&9R;VT@
M<W1A<G0@;V8@1DE,17,@:7,@)&]F9G-E="(I.PIS965K(%]&2"P@)&UA9VEC
M7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE("T@)&]F9G-E="P@,#L*)'-T87)T
M7V]F7T9)3$5?<V5C=&EO;B`]('1E;&P@7T9(.PIM>2`E<F5Q=6ER95]L:7-T
M.PIR96%D(%]&2"P@)&)U9BP@-#L@("`@("`@("`@("`@("`@("`@("`@("`@
M("`C(')E860@=&AE(&9I<G-T(")&24Q%(@IW:&EL92`H)&)U9B!E<2`B1DE,
M12(I('L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A
M8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ<5M5
M;G!A8VMI;F<@1DE,12`B)&9U;&QN86UE(BXN+ETI.PIM>2`D8W)C(#T@*"`D
M9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F
M.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H
M+BHI*%PN+BHI?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U
M9BP@=6YP86-K*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N9"`D
M97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA;64@
M/2!?<V%V95]A<R@B)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!4CHZ2&5A
M=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2.CI(
M96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*96QS
M92!["B1-;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PIB=68@/3X@)&)U9BP*
M8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN86UE+`I].PHD<F5Q=6ER95]L
M:7-T>R1F=6QL;F%M97TK*SL*?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A
M;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T
M=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D:6YF;R`]("1-
M;V1U;&5#86-H97LD;6]D=6QE?3L*<F5T=7)N('5N;&5S<R`D:6YF;SL*9&5L
M971E("1R97%U:7)E7VQI<W1[)&UO9'5L97T["B1)3D-[)&UO9'5L97T@/2`B
M+VQO861E<B\D:6YF;R\D;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,14%.?2!A
M;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I
M;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`B0V%N)W0@8W)E871E('1E;7`@9FEL
M93H@)"$B.PHD9F@M/F)I;FUO9&4H*3L*)&9H+3YP<FEN="@D:6YF;RT^>V)U
M9GTI.PHD9F@M/G-E96LH,"P@,"D["G)E='5R;B`D9F@["GT*96QS92!["FUY
M("1F:6QE;F%M92`](%]S879E7V%S*"(D:6YF;RT^>V-R8WTN<&TB+"`D:6YF
M;RT^>V)U9GTI.PHD:6YF;RT^>V9I;&5](#T@)&9I;&5N86UE.PIO<&5N(&UY
M("1F:"P@)SPZ<F%W)RP@)&9I;&5N86UE(&]R(&1I92!Q<5M#86XG="!R96%D
M("(D9FEL96YA;64B.B`D(5T["G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R
M87!P:6YG(&9A:6QE9#H@8V%N)W0@9FEN9"!M;V1U;&4@)&UO9'5L92$B.PI]
M+"!`24Y#*3L*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y
M.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V
M>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/
M.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q
M=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D
M9FEL96YA;64@/7X@+T)31%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP
M;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL
M96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD
M+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*:68@
M*"1B=68@;F4@)%!+6DE07TU!1TE#*2!["F]U=',H<7%;3F\@>FEP(&9O=6YD
M(&%F=&5R($9)3$4@<V5C=&EO;B!I;B!F:6QE("(D<')O9VYA;64B72D["FQA
M<W0@34%'24,@.PI]"B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L@("`@
M("`@("`@("`@("`@(R!S=&%R="!O9B!Z:7`*?0IM>2!`<&%R7V%R9W,["FUY
M("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*9&5L971E
M("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I>F4@*%)%55-%(&UA>2!B
M92!A('-E8W5R:71Y('!R;V)L96TI"FEF("@A)'-T87)T7W!O<R!O<B`H)$%2
M1U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES
M=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU
M("`@=6YI;G-T86QL7W!A<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(*
M*3L*:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI
M9G0@0$%21U8["B1%3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*
M?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I
M;F,["G=H:6QE("A`05)'5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q
M<&EU<U1V72DH+BHI+R!O<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@
M0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B
M=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A
M<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE
M;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@
M*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q
M("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E
M;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92!Q<5M#86XG="!O<&5N(&QO9R!F
M:6QE("(D,B(Z("0A73L*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N
M86UE(#T@)#(["GT*<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T
M7V-M9'LD,7TI('L*9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC
M*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I
M('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`
M05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*
M?0II9B`H)&]U="D@>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C
M:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PI]"FUY("1P87(@/2!S
M:&EF="A`05)'5BD["FUY("1Z:7`["FEF("AD969I;F5D("1P87(I('L*;W!E
M;B!M>2`D9F@L("<\.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T(&9I;F0@
M<&%R(&9I;&4@(B1P87(B.B`D(5T["F)L97-S*"1F:"P@)TE/.CI&:6QE)RD[
M"B1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I
M;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@
M*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!A<B)=
M.PI]"FUY("5M971A7W!A<B`](&1O('L*:68@*"1Z:7`@86YD(&UY("1M971A
M(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@<R\N
M*EYP87(Z)"\O;7,["B1M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]?B`O
M7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*?3L*:68@*&1E9FEN960@)'!A<BD@
M>PIO<&5N(&UY("1P:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@
M<F5A9"!P87(@9FEL92`B)'!A<B(Z("0A73L*;7D@)&)U9CL*<F5A9"`D<&@L
M("1B=68L(#0["F1I92!Q<5LB)'!A<B(@:7,@;F]T(&$@<&%R(&9I;&5=('5N
M;&5S<R`D8G5F(&5Q("102UI)4%]-04=)0SL*8VQO<V4@)'!H.PI]"D-R96%T
M95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)
M3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?4D174B@I('P@24\Z
M.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP**2!O<B!D:64@<7%;0V%N)W0@8W)E
M871E(&9I;&4@(B1O=70B.B`D(5T["B1F:"T^8FEN;6]D92@I.PIS965K(%]&
M2"P@,"P@,#L*;7D@)&QO861E<CL*:68@*&1E9FEN960@)'-T87)T7V]F7T9)
M3$5?<V5C=&EO;BD@>PIR96%D(%]&2"P@)&QO861E<BP@)'-T87)T7V]F7T9)
M3$5?<V5C=&EO;CL*?2!E;'-E('L*;&]C86P@)"\@/2!U;F1E9CL*)&QO861E
M<B`](#Q?1D@^.PI]"FEF("@A)$5.5GM005)?5D520D%424U](&%N9"`D;&]A
M9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R
M.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&QO
M861E<BP@)#`I.PI]"B1F:"T^<')I;G0H)&QO861E<BD*;W(@9&EE('%Q6T5R
M<F]R('=R:71I;F<@;&]A9&5R('1O("(D;W5T(CH@)"%=.PII9B`H)&)U;F1L
M92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y
M;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY
M($!I;F,@/2!G<F5P('L@(2]"4T1004XO('T*9W)E<"!["B@D8G5N9&QE(&YE
M("=S:71E)RD@;W(**"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP
M?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`
M24Y#.PIS?"\K?"]\9RP@<WPO)'Q\(&9O<F5A8V@@0&EN8SL*;7D@)69I;&5S
M.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA3&]A9&5R.CID;%]S:&%R961?;V)J
M96-T<RP@=F%L=65S("5)3D,["FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N
M9FEG>VQI8E]E>'1].R`@("`@("`@(",@6%A8(&QI8E]E>'0@=G,@9&QE>'0@
M/PIM>2`E=W)I='1E;CL*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)69I
M;&5S*2!["FUY("@D9FEL92P@)&YA;64I.PII9B`H9&5F:6YE9"AM>2`D9F,@
M/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1K97E]*2D@>PHH)&9I;&4L("1N
M86UE*2`]("@D:V5Y+"`D9F,I.PI]"F5L<V4@>PIF;W)E86-H(&UY("1D:7(@
M*$!I;F,I('L*:68@*"1K97D@/7X@;7Q>7%$D9&ER7$4O*"XJ*21\:2D@>PHH
M)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D,2D["FQA<W0["GT*:68@*"1K97D@
M/7X@;7Q>+VQO861E<B];7B]=*R\H+BHI)'PI('L*:68@*&UY("1R968@/2`D
M36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q
M*3L*;&%S=#L*?0II9B`H+68@(B1D:7(O)#$B*2!["B@D9FEL92P@)&YA;64I
M(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T.PI]"GT*?0I]"FYE>'0@=6YL97-S
M(&1E9FEN960@)&YA;64["FYE>'0@:68@)'=R:71T96Y[)&YA;65]*RL["FYE
M>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<
M120O:3L*;W5T<RAS<')I;G1F*'%Q6U!A8VMI;F<@1DE,12`B)7,B+BXN72P@
M<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE*2D["FUY("1C;VYT
M96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[8G5F
M?3L*?0IE;'-E('L*;&]C86P@)"\@/2!U;F1E9CL*;W!E;B!M>2`D=&@L("<\
M.G)A=R<L("1F:6QE(&]R(&1I92!Q<5M#86XG="!R96%D("(D9FEL92(Z("0A
M73L*)&-O;G1E;G0@/2`\)'1H/CL*8VQO<V4@)'1H.PI005(Z.D9I;'1E<CHZ
M4&]D4W1R:7`M/F%P<&QY*%PD8V]N=&5N="P@(CQE;6)E9&1E9#XO)&YA;64B
M*0II9B`A)$5.5GM005)?5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP
M;7QI>'QA;"DD+VD["E!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0M/FYE=RT^
M87!P;'DH7"1C;VYT96YT+"`D9FEL92P@)&YA;64I.PI]"B1F:"T^<')I;G0H
M(D9)3$4B+`IP86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI+`IS<')I;G1F
M*"(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E
M;G0I+"`D;F%M92DL"G!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2P*)&-O
M;G1E;G0I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG(&5M8F5D9&5D($9)3$4@
M=&\@(B1O=70B.B`D(5T["F]U=',H<7%;5W)I='1E;B!A<R`B)&YA;64B72D[
M"GT*?0II9B`H)'II<"D@>PHD>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I
M(#T]($%R8VAI=F4Z.EII<#HZ05I?3TL*;W(@9&EE('%Q6T5R<F]R('=R:71I
M;F<@>FEP('!A<G0@;V8@(B1O=70B73L*?0II9B`H)&UE=&%?<&%R>V-L96%N
M?2D@>PHD9F@M/G!R:6YT*")<,$-,14%.(BD["GT*96QS92!["FEF("@A9&5F
M:6YE9"`D8V%C:&5?;F%M92D@>PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE
M=R@Q*3L*<V5E:R`D9F@L(#`L(#`["B1C='@M/F%D9&9I;&4H)&9H*3L*<V5E
M:R`D9F@L(#`L(#(["B1C86-H95]N86UE(#T@)&-T>"T^:&5X9&EG97-T.PI]
M"B1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`D8V%C:&5?
M;F%M95]S:7IE.PHD8V%C:&5?;F%M92`N/2`B7#`B('@@*"1C86-H95]N86UE
M7W-I>F4@+2!L96YG=&@@)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*"1C86-H
M95]N86UE+`HB7#!#04-(12(I.PI]"FUY("1O9F9S970@/2`D9F@M/G1E;&P@
M+2!L96YG=&@H)&QO861E<BD["B1F:"T^<')I;G0H<&%C:R@G3B<L("1O9F9S
M970I+`HD4$%27TU!1TE#*3L*)&9H+3YC;&]S92!O<B!D:64@<7%;17)R;W(@
M=W)I=&EN9R!T<F%I;&5R(&]F("(D;W5T(CH@)"%=.PIC:&UO9"`P-S4U+"`D
M;W5T.PIE>&ET.PI]"GL*;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S
M.PI?9FEX7W!R;V=N86UE*"D["G)E<75I<F4@4$%2.PI005(Z.DAE879Y.CI?
M:6YI=%]D>6YA;&]A9&5R*"D["GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U
M:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D9F@@/2!)3SHZ1FEL92T^;F5W.R`@
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(R!!<F-H:79E.CI::7`@;W!E
M<F%T97,@;VX@86X@24\Z.DAA;F1L90HD9F@M/F9D;W!E;BAF:6QE;F\H7T9(
M*2P@)W(G*2!O<B!D:64@<7%;9F1O<&5N*"D@9F%I;&5D.B`D(5T["D%R8VAI
M=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*"US(%]&2"D["FUY("1Z:7`@/2!!<F-H
M:79E.CI::7`M/FYE=SL**"1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L
M("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@
M<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!R;V=N86UE(ET["D%R
M8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*#8T("H@,3`R-"D["G!U<V@@0%!!
M4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@
M/2`D>FEP.PIO=71S*")%>'1R86-T:6YG('II<"XN+B(I.PII9B`H9&5F:6YE
M9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P
M;VEN="$*9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*
M;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE
M(#T@)&UE;6)E<BT^9FEL94YA;64["FYE>'0@=6YL97-S("1M96UB97)?;F%M
M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M
M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@)#$["FUY
M("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%
M35!]+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA;64@)B8@+7,@
M7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*;W5T<RAQ<5M3
M:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T
M<R!A="`B)&1E<W1?;F%M92)=*3L*?2!E;'-E('L*;W5T<RAQ<5M%>'1R86-T
M:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BXN+ETI.PHH)&UE
M;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I(#T]($%R8VAI
M=F4Z.EII<#HZ05I?3TLH*2D*;W(@9&EE('%Q6T5R<F]R(&5X=')A8W1I;F<@
M>FEP(&UE;6)E<B!T;R`B)&1E<W1?;F%M92)=.PIC:&UO9"@P-34U+"`D9&5S
M=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H)%!!
M4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID:64@/#P@(BXB('5N;&5S<R!`
M05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM
M;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN<&P@70HD,"!;("U"?"UB
M(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%3E9[4$%27U!23T=.04U%?2`]
M("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A=&50
M871H('L*;7D@*"1N86UE*2`]($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE
M.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M
M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL93HZ
M4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A
M=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER95]M
M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E<75I<F4@1'EN84QO861E<CL*<F5Q
M=6ER92!I;G1E9V5R.PIR97%U:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N:6YG
M<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E($-A<G`["G)E<75I<F4@0V%R<#HZ
M2&5A=GD["G)E<75I<F4@17)R;F\["G)E<75I<F4@17AP;W)T97(Z.DAE879Y
M.PIR97%U:7)E($5X<&]R=&5R.PIR97%U:7)E($9C;G1L.PIR97%U:7)E($9I
M;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO861E
M<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q=6ER
M92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER92!!
M<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["G)E<75I<F4@4$%2
M.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@4$%2.CI$:7-T.PIR97%U
M:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*<F5Q=6ER92!005(Z.D9I;'1E
M<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T=')I8G5T97,["F5V86P@>R!R
M97%U:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER92!7:6XS,B!].PIE=F%L('L@
M<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*979A;"![(')E<75I<F4@07)C:&EV
M93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ
M3F%M961#87!T=7)E('T["F5V86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER
M92!097)L24\Z.G-C86QA<B!].PIE=F%L('L@<F5Q=6ER92!U=&8X('T["GT*
M<W5B(%]S971?<&%R7W1E;7`@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0
M?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2!["B1P87)?=&5M<"`]
M("0Q.PIR971U<FX["GT*9F]R96%C:"!M>2`D<&%T:"`H"BAM87`@)$5.5GLD
M7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI
M+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D**2!["FYE>'0@=6YL97-S(&1E9FEN
M960@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*;7D@)'5S97)N
M86UE.PIM>2`D<'=U:60["F5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI
M(&EF(&1E9FEN960@)#X[?3L*:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.
M86UE*2`I('L*)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["GT*96QS
M:68@*&1E9FEN960@)'!W=6ED*2!["B1U<V5R;F%M92`]("1P=W5I9#L*?0IE
M;'-E('L*)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52
M?2!\?"`G4UE35$5-)SL*?0IM>2`D<W1M<&1I<B`]("(D<&%T:"1S>7-[7V1E
M;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M
M<&1I<BP@,#<U-3L*;7D@)&-A8VAE7V1I<CL*:68@*"1%3E9[4$%27T-,14%.
M?2D@>PHD8V%C:&5?9&ER(#T@(G1E;7`M)"0B.PI]"F5L<V4@>PIO<&5N(&UY
M("1F:"P@(CPZ<F%W(BP@)'!R;V=N86UE(&]R(&1I92!Q<5M#86XG="!R96%D
M("(D<')O9VYA;64B.B`D(5T["FEF("@H;7D@)&UA9VEC7W!O<R`](&9I;F1?
M<&%R7VUA9VEC*"1F:"DI(#X](#`I('L*<V5E:R`D9F@L("1M86=I8U]P;W,*
M+2`D1DE,15]O9F9S971?<VEZ90HM(&QE;F=T:"@B7#!#04-(12(I+"`P.PIM
M>2`D8G5F.PIR96%D("1F:"P@)&)U9BP@;&5N9W1H*")<,$-!0TA%(BD["FEF
M("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K("1F:"P@)&UA9VEC7W!O<PHM
M("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N9W1H*")<,$-!0TA%(BD*+2`D8V%C
M:&5?;F%M95]S:7IE+"`P.PIR96%D("1F:"P@)&)U9BP@)&-A8VAE7VYA;65?
M<VEZ93L*)&)U9B`]?B!S+UPP+R]G.PHD8V%C:&5?9&ER(#T@(F-A8VAE+21B
M=68B.PI]"GT*8VQO<V4@)&9H.PI]"FEF("@A)&-A8VAE7V1I<BD@>PHD8V%C
M:&5?9&ER(#T@(G1E;7`M)"0B.PHD14Y6>U!!4E]#3$5!3GT@/2`Q.PI]"B1S
M=&UP9&ER("X]("(D<WES>U]D96QI;7TD8V%C:&5?9&ER(CL*;6MD:7(@)'-T
M;7!D:7(L(#`W-34["B1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["FQA<W0[
M"GT*)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[
M4$%27U1%35!](#U^("\H+BLI+SL*?0IS=6(@7W-A=F5?87,@>PIM>2`H)&YA
M;64L("1C;VYT96YT<RP@)&UO9&4I(#T@0%\["FUY("1F=6QL;F%M92`]("(D
M<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@*"UE("1F=6QL;F%M92D@>PIM>2`D
M=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D(CL*;7D@)&9H.PHH;W!E;B`D9F@L
M("<^.G)A=R<L("1T96UP;F%M92D*)B8@*'!R:6YT("1F:"`D8V]N=&5N=',I
M"B8F("AC;&]S92`D9F@I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG("(D=&5M
M<&YA;64B.B`D(5T["F-H;6]D("1M;V1E+"`D=&5M<&YA;64@:68@9&5F:6YE
M9"`D;6]D93L*<F5N86UE*"1T96UP;F%M92P@)&9U;&QN86UE*2!O<B!U;FQI
M;FLH)'1E;7!N86UE*3L*?0IR971U<FX@)&9U;&QN86UE.PI]"G-U8B!?<V5T
M7W!R;V=N86UE('L*:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345](&%N
M9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]
M("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF("@D14Y6>U!!4E]414U0?2!A
M;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD
M<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE
M+"`D<WES>U]D96QI;7TI("L@,2D["GT*:68@*"$D14Y6>U!!4E]04D]'3D%-
M17T@;W(@:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI(#X](#`I('L*
M:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR971U<FX@:68@
M+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE)'-Y<WM?97AE?2(I('L*)'!R
M;V=N86UE("X]("1S>7-[7V5X97T["G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@
M)&1I<B`H<W!L:70@+UQ1)'-Y<WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI
M('L*;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@
M)$5.5GM005)?5$5-4'T["B1D:7(@/7X@<R]<421S>7-[7V1E;&EM?5Q%)"\O
M.PHH*"1P<F]G;F%M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y
M<WM?97AE?2(I+"!L87-T*0II9B`M<R`B)&1I<B1S>7-[7V1E;&EM?21P<F]G
M;F%M921S>7-[7V5X97TB.PHH*"1P<F]G;F%M92`]("(D9&ER)'-Y<WM?9&5L
M:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U]
M)'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D<')O
M9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P<F]G
M;F%M92P@)'-Y<WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD<WES
M>U]D96QI;7TD<')O9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D
M.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z
M.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P
M=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421S>7-[7V1E;&EM?5Q%
M*2\D<'=D)'-Y<WM?9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!345](#T@)'!R
M;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?96YV('L*:68@*"`D14Y6>U!!4E])
M3DE424%,25I%1'TK*R`]/2`Q("D@>PIR971U<FX["GT@96QS92!["B1%3E9[
M4$%27TE.251)04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%1"!414U0
M($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%("D@*2!["F1E;&5T92`D14Y6
M>R)005)?)%\B?3L*?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)5
M1R`O*2!["B1%3E9[(E!!4E\D7R)](#T@)$5.5GLB4$%27T=,3T)!3%\D7R)]
M(&EF(&5X:7-T<R`D14Y6>R)005)?1TQ/0D%,7R1?(GT["GT*:68@*"1%3E9[
M4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#3$5!3GT["GT*?0IS=6(@
M;W5T<R!["G)E='5R;B!I9B`D<75I970["FEF("@D;&]G9F@I('L*<')I;G0@
M)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B
M(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D
M969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E
M>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R
M8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*<&%C:V%G92!M86EN.PIR97%U:7)E
M(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP
M;W)T*$!P87)?87)G<RD["F1I92!Q<5MP87(N<&PZ($-A;B=T(&]P96X@<&5R
M;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O
M<GE<;ET*=6YL97-S("UE("1P<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%
M.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID
M:64@)$`@:68@)$`["GT["B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%
M.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K
M*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)23U(["C$["E]?14Y$
M7U\*``$;`SL(`0``(````#"/__\@`0``D(___T0!```8D/__;`$``,B1___4
M`0``L)+__P`"``!8D___,`(``+B4__]D`@``\);__YP"``"`E___R`(``)R8
M__\``P``E)G__SP#``#\F?__=`,``'2:__^<`P``?)K__[`#``#XG/__Y`,`
M`"B=__\4!```B)W__U@$``!4G___B`0``-2?__^P!```-*#__]@$```4HO__
M$`4``#2B__\P!0``**/__V0%``#,J?__G`4``%RL___0!0``Q*S__S`&``#(
MN/__:`8``"RY__^(!@``1+K__[0&``"XN___I`$``$"\__^0`0``E+S__P`&
M```0``````````%Z4@`"?`X!&PP-`"`````8````"([__V``````1`T,3(0&
MA06+!(T#C@)"#`L$`"0````\````1([__X@`````1`T,2(0(A0>&!H<%BP2-
M`XX"0@P+!``@````9````*2.__^P`0```$8-#$2'!8L$C0..`D(,"P0````0
M````B````*BZ__]4`````````"P```"<````#+K__X@`````1`T,1(0&A06+
M!(T#C@)$#`L$:`P-&$+.S<O%Q`X$`"@```#,````[(___^@`````0@T,1(0*
MA0F&"(<'B`:)!8L$C0..`D0,"P0`+````/@```"HD/__J`````!"#0Q$A`B%
M!X8&AP6+!(T#C@)"#`L$`D(*#`T@0@L`,````"@!```@D?__8`$```!$#0Q&
MA`N%"H8)APB(!XD&B@6+!(T#C@)"#`L$7`H,#2Q""S0```!<`0``3)+__S@"
M````0@T,1(0+A0J&"8<(B`>)!HH%BP2-`XX"0@P+!`*6"@P-+$(+````*```
M`)0!``!,E/__D`````!$#0Q&A`:%!8L$C0..`D(,"P1H"@P-&$(+```T````
MP`$``+"4__\<`0```$0-#$*$"X4*A@F'"(@'B0:*!8L$C0..`D(,"P0"6`H,
M#2Q""P```#@```#X`0``E)7___@`````1`T,0H0&A06+!(T#C@)"#`L$`E@*
M#`T80@M."@P-&$+.S<O%Q`X$0@L``#0````T`@``4);__V@`````1`T,2(0(
MA0>&!H<%BP2-`XX"0@P+!%@,#2!"SLW+Q\;%Q`X$````)````&P"``"`EO__
M>`````!$#0Q$A`:%!8L$C0..`D0,"P1D#`T8`!````"4`@``T);__P@`````
M````,````*@"``#$EO__?`(```!$#0Q&A`N%"H8)APB(!XD&B@6+!(T#C@)$
M#`L$?`H,#2Q""RP```#<`@``#)G__S``````0@T,1(0&A06+!(T#C@)"#`L$
M3`P-&$+.S<O%Q`X$`$`````,`P``#)G__V``````0@T,0H0&A06+!(T#C@)$
M#`L$5`H,#1A"SLW+Q<0.!$(+1@H,#1A"SLW+Q<0.!$(+````+````%`#```H
MF?__S`$```!$#0Q(A`>%!H8%BP2-`XX"0@P+!`*4"@P-'$(+````)````(`#
M``#$FO__@`````!$#0Q(A`6+!(T#C@)"#`L$:`H,#11""R0```"H`P``')O_
M_V``````0@T,0H`$@0."`H,!1(L(C0>.!D(,"Q0T````T`,``%2;___@`0``
M`$0-#$*$"X4*A@F'"(@'B0:*!8L$C0..`D(,"P0"M`H,#2Q""P```!P````(
M!```_)S__R``````0@T,0HL$C0..`D(,"P0`,````"@$``#\G/__]`````!$
M#0Q&A`F%"(8'AP:(!8L$C0..`D(,"P0"7@H,#21""P```#0```!<!```O)W_
M_Z0&````0@T,1(0+A0J&"8<(B`>)!HH%BP2-`XX"0@P+!`,X`0H,#2Q""P``
M,````)0$```HI/__D`(```!$#0Q(A`F%"(8'AP:(!8L$C0..`D(,"P0"T@H,
M#21""P```"P```#(!```A*;__V@`````0@T,0H0&A06+!(T#C@)"#`L$:`P-
M&$+.S<O%Q`X$`"P```#X!```C+;__Y`"````0@T,1(0(A0>&!H<%BP2-`XX"
M0@P+!`+,"@P-($(+`#0````H!0``C*;__P0,````1`T,1(0+A0J&"8<(B`>)
M!HH%BP2-`XX"1`P+!`/N!0H,#2Q""P``'````&`%``!8LO__9`````!"#0Q$
MBP2-`XX"0@P+!``H````@`4``)RR__\8`0```$(-#$*$"H4)A@B'!X@&B06+
M!(T#C@)>#`L$`#P```"L!0``B+/__W0!````0@T,0H0*A0F&"(<'B`:)!8L$
MC0..`E(,"P0"F`H,#2A"SLW+R<C'QL7$#@1""P``````^$,``'!#````````
M`0````$````!````RP(```$```#5`@```0```.,"```!````"0,```\```"B
M!```&0```+".`0`;````!````!H```"TC@$`'`````0````$````>`$```4`
M``!T"P``!@```+0$```*````ZP0```L````0````%0`````````#````K(\!
M``(````8`@``%````!$````7````B!$``!$```!@$```$@```"@!```3````
M"````/O__V\````(^O__;QD`````````````````````````````````````
M````````````````````O(X!````````````H!,``*`3``"@$P``H!,``*`3
M``"@$P``H!,``*`3``"@$P``H!,``*`3``"@$P``H!,``*`3``"@$P``H!,`
M`*`3``"@$P``H!,``*`3``"@$P``H!,``*`3``"@$P``H!,``*`3``"@$P``
MH!,``*`3``"@$P``H!,``*`3``"@$P``H!,``*`3``"@$P``H!,``*`3``"@
M$P``H!,``*`3``"@$P``H!,``*`3``"@$P``H!,``*`3``"@$P``H!,``*`3
M``"@$P``H!,``*`3``"@$P``H!,``*`3``"@$P``H!,``*`3``"@$P``H!,`
M`*`3``"@$P``H!,``*`3``"@$P``H!,``+B.`0``````>!$```````"PC@$`
M````````````````P)$!`'@1````````M(X!``````!DD0$`````````````
M````O(X!``````"$D0$``````""1`0"$,0``@)$!`"21`0`*4$%2+G!M"@``
M``!`2@``!$<````````42```&$@``#1*``!@1P``/$H````````@2@``*$H`
M``````!(2@``1T-#.B`H3F5T0E-$(&YB-"`R,#(P,#@Q,"D@-RXU+C``1T-#
M.B`H;F(T(#(P,C`P.#$P*2`W+C4N,``D3F5T0E-$.B!C<G0P+E,L=B`Q+C0@
M,C`Q."\Q,2\R-B`Q-SHS-SHT-"!J;V5R9R!%>'`@)``D3F5T0E-$.B!C<G0P
M+6-O;6UO;BYC+'8@,2XR,R`R,#$X+S$R+S(X(#(P.C$R.C,U(&-H<FES=&]S
M($5X<"`D`"1.971"4T0Z(&-R=&DN4RQV(#$N,2`R,#$R+S`X+S$S(#`R.C0Y
M.C`T(&UA='0@17AP("0`)$YE=$)31#H@8W)T8F5G:6XN8RQV(#$N,3<@,C`Q
M."\Q,B\R."`Q.#HQ-SHQ,2!C:')I<W1O<R!%>'`@)``D3F5T0E-$.B!C<G1E
M;F0N4RQV(#$N,B`R,#$S+S$R+S(P(#$U.C,U.C0X(&IO97)G($5X<"`D````
M`/'/`@`````````````````(````"`````@````(````&P````$`````````
M`"HJ*B!.;R!,86)E;"!0<F]V:61E9"`J*BH``/'/`@`````````````````(
M````"`````@````(````&P````$``````````"HJ*B!.;R!,86)E;"!0<F]V
M:61E9"`J*BH`038```!A96%B:0`!+`````5#;W)T97@M03@`!@H'00@!"0(*
M`A($%`$5`1<#&`$:`AP!(@%$`0`N<VAS=')T86(`+FEN=&5R<``N;F]T92YN
M971B<V0N:61E;G0`+FYO=&4N;F5T8G-D+G!A>``N;F]T92YN971B<V0N;6%R
M8V@`+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YR96PN9'EN`"YR96PN<&QT`"YT
M97AT`"YR;V1A=&$`+F5H7V9R86UE7VAD<@`N96A?9G)A;64`+FEN:71?87)R
M87D`+F9I;FE?87)R87D`+FIC<@`N9'EN86UI8P`N9V]T`"YD871A`"YB<W,`
M+F-O;6UE;G0`+E-53E=?8W1F`"Y!4DTN871T<FEB=71E<P``````````````
M``````````````````````````````````````````L````!`````@```!0!
M```4`0``%P```````````````0`````````3````!P````(````L`0``+`$`
M`!@```````````````0`````````)@````<````"````1`$``$0!```4````
M```````````$`````````#<````'`````@```%@!``!8`0``(```````````
M````!`````````!*````!0````(```!X`0``>`$``#P#```&``````````0`
M```$````4`````L````"````M`0``+0$``#`!@``!P````,````$````$```
M`%@````#`````@```'0+``!T"P``ZP0``````````````0````````!@````
M"0````(```!@$```8!```"@!```&``````````0````(````:0````D```!"
M````B!$``(@1```8`@``!@```!,````$````"````&T````!````!@```*`3
M``"@$P``.`,`````````````!`````0```!R`````0````8```#8%@``V!8`
M``0P``````````````0`````````>`````$````"````W$8``-Q&``#<0```
M```````````$`````````(`````!`````@```+B'``"XAP``#`$`````````
M````!`````````".`````0````(```#$B```Q(@``.P%``````````````0`
M````````F`````X````#````L(X!`+".```$```````````````$````!```
M`*0````/`````P```+2.`0"TC@``!```````````````!`````0```"P````
M`0````,```"XC@$`N(X```0```````````````0`````````M0````8````#
M````O(X!`+R.``#P````!P`````````$````"````+X````!`````P```*R/
M`0"LCP``=`$`````````````!`````0```##`````0````,````@D0$`()$`
M`$@```````````````0`````````R0````@````#````@)$!`&B1``!$````
M``````````!``````````,X````!````,`````````!HD0``.P``````````
M`````0````$````?`````0``````````````HY$``"(!``````````````$`
M````````UP````$``````````````,B2``"/```````````````$````````
M`.$````#``!P``````````!7DP``-P```````````````0`````````!````
D`P``````````````CI,``/$```````````````$`````````
